==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/StackedLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalStackedSeriesBase } from "./HorizontalStackedSeriesBase";
import { markType } from "igniteui-react-core";
import { AxisRange } from "./AxisRange";
import { StackedSeriesView } from "./StackedSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var StackedLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedLineSeries, _super);
    function StackedLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = StackedLineSeries.$;
        return _this;
    }
    StackedLineSeries.prototype.get_ex = function () {
        return true;
    };
    StackedLineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.pp(false);
    };
    StackedLineSeries.prototype.cg = function () {
        return new StackedLineSeriesView(this);
    };
    StackedLineSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.yk = a;
    };
    StackedLineSeries.prototype.aq = function (a) {
        if (this.itemsSource == null) {
            return null;
        }
        if (a == this.xAxis) {
            return new AxisRange(0, this.c6.count - 1);
        }
        if (a == this.yAxis) {
            this.x3();
            return new AxisRange(this.xu, this.xt);
        }
        return null;
    };
    StackedLineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    Object.defineProperty(StackedLineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.wi;
        },
        enumerable: false,
        configurable: true
    });
    StackedLineSeries.$t = markType(StackedLineSeries, 'StackedLineSeries', HorizontalStackedSeriesBase.$);
    return StackedLineSeries;
}(HorizontalStackedSeriesBase));
export { StackedLineSeries };
/**
 * @hidden
 */
var StackedLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedLineSeriesView, _super);
    function StackedLineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    StackedLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c3.ua = Defaults.e;
        }
    };
    StackedLineSeriesView.$t = markType(StackedLineSeriesView, 'StackedLineSeriesView', StackedSeriesView.$);
    return StackedLineSeriesView;
}(StackedSeriesView));
export { StackedLineSeriesView };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/StackedLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalStackedSeriesBase } from "./HorizontalStackedSeriesBase";
import { markType } from "igniteui-react-core";
import { AxisRange } from "./AxisRange";
import { ChartSelection } from "./ChartSelection";
import { List$1 } from "igniteui-react-core";
import { StackedSeriesView } from "./StackedSeriesView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var StackedLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedLineSeries, _super);
    function StackedLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = StackedLineSeries.$;
        return _this;
    }
    StackedLineSeries.prototype.bj = function () {
        return new StackedLineSeries();
    };
    StackedLineSeries.prototype.get_fj = function () {
        return true;
    };
    StackedLineSeries.prototype.ac = function () {
        _super.prototype.ac.call(this);
        this.rp(false);
    };
    StackedLineSeries.prototype.cr = function () {
        return new StackedLineSeriesView(this);
    };
    StackedLineSeries.prototype.qz = function (a) {
        _super.prototype.qz.call(this, a);
        this.abx = a;
    };
    StackedLineSeries.prototype.ay = function (a) {
        if (this.itemsSource == null) {
            return null;
        }
        if (a == this.xAxis) {
            return new AxisRange(0, this.dm.count - 1);
        }
        if (a == this.yAxis) {
            this.abg();
            return new AxisRange(this.aa7, this.aa6);
        }
        return null;
    };
    StackedLineSeries.prototype.preferredCategoryMode = function (a) {
        return 0;
    };
    StackedLineSeries.prototype.ak = function (a, b) {
        var c = new List$1(ChartSelection.$, 0);
        this.p1(a, c, b);
        return c.toArray();
    };
    StackedLineSeries.prototype.p1 = function (a, b, c) {
        this.z7(a, b, c, this.yo, 0);
    };
    Object.defineProperty(StackedLineSeries.prototype, "useHighMarkerFidelity", {
        get: function () {
            return this.zl;
        },
        enumerable: false,
        configurable: true
    });
    StackedLineSeries.$t = markType(StackedLineSeries, 'StackedLineSeries', HorizontalStackedSeriesBase.$);
    return StackedLineSeries;
}(HorizontalStackedSeriesBase));
export { StackedLineSeries };
/**
 * @hidden
 */
var StackedLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedLineSeriesView, _super);
    function StackedLineSeriesView(a) {
        return _super.call(this, a) || this;
    }
    StackedLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.c5.w5 = Defaults.e;
        }
    };
    StackedLineSeriesView.$t = markType(StackedLineSeriesView, 'StackedLineSeriesView', StackedSeriesView.$);
    return StackedLineSeriesView;
}(StackedSeriesView));
export { StackedLineSeriesView };
